Module flake

Module flake 

Re-export flake lock types from sui-compat where they canonically live.

Structs

FlakeLock
A parsed and validated flake.lock file.
FlakeNode
A single node in the input graph.
LockedInput
Locked (pinned) revision of a flake input.
OriginalInput
Original (un-locked) input specification.

Enums

FlakeLockError
Errors that can occur while parsing or resolving a flake lock file.
InputRef
A reference to another node in the input graph.