render_tree

Function render_tree 

pub fn render_tree(v: &Value) -> Result<String, String>
Render a tree-walker Value to the normalized differential form.

Errors

Propagates any force error as its Display string (the differential must see errors as errors, not swallow them into <<thunk:error>>).