pub fn capture_cycle(thunk_id: usize) -> ForceChainExpand description
Capture the cycle portion of the force stack starting from the
frame whose thunk_id matches the blackholed thunk.
pub fn capture_cycle(thunk_id: usize) -> ForceChainCapture the cycle portion of the force stack starting from the
frame whose thunk_id matches the blackholed thunk.