pub fn clear_ident_cache()Expand description
Clear the identifier symbol cache.
Call between independent top-level evaluations to reclaim memory. The cache grows unboundedly during a single evaluation pass.
pub fn clear_ident_cache()Clear the identifier symbol cache.
Call between independent top-level evaluations to reclaim memory. The cache grows unboundedly during a single evaluation pass.